@@ -24,6 +24,8 @@ only be called via that package.
 This package implements the WMI-specific methods of
 Win32::Process::Info.
 
+This package returns Windows process IDs, even under Cygwin.
+
 The following methods should be considered public:
 
 =over 4
@@ -35,8 +37,9 @@ package Win32::Process::Info::WMI;
 use strict;
 use warnings;
 
-use base qw{Win32::Process::Info};
-our $VERSION = '1.019';
+use base qw{ Win32::Process::Info };
+
+our $VERSION = '1.020';
 
 use vars qw{%mutator};
 use Carp;
@@ -208,9 +211,10 @@ be present.
 
 sub _get_proc_objects {
 my $self = shift;
+my $my_pid = $self->My_Pid();
 my @procs = @_ ?
     map {
-	my $pi = $_ eq '.' ? $$ : $_;
+	my $pi = $_ eq '.' ? $my_pid : $_;
 	my $obj = $self->{wmi}->Get ("Win32_Process='$pi'");
 	Win32::OLE->LastError ? () : ($obj)	
 	} @_ :
@@ -411,7 +415,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 Copyright (C) 2001-2005 by E. I. DuPont de Nemours and Company, Inc.
 
-Copyright (C) 2007, 2010-2011 by Thomas R. Wyant, III
+Copyright (C) 2007, 2010-2011, 2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
